@@ -55,9 +55,20 @@ pub enum ShapeType {
 impl Shape {
     /// Update the position of the shape.
     pub(crate) fn update_pos(&mut self, pos: Vec2) {
+        let prev_pos = self.pos.pos;
         self.pos.pos = pos;
         match &mut self.shape_type {
-            ShapeType::Drawing(s) => s.iter_mut().for_each(|v| v.update_pos(pos)),
+            ShapeType::Drawing(s) => {
+                let self_pos = self.pos.pos;
+                s.iter_mut().for_each(|v| {
+                    v.update_pos(self_pos + pos);
+                });
+            }
+            ShapeType::Line { from, to } => {
+                let delta = pos - prev_pos;
+                *from += delta;
+                *to += delta;
+            }
             _ => {}
         }
     }
@@ -65,7 +76,13 @@ impl Shape {
     /// Update the scale of the shape.
     pub(crate) fn update_scale(&mut self, scale: f32) {
         match &mut self.shape_type {
-            ShapeType::Drawing(s) => s.iter_mut().for_each(|v| v.update_scale(scale)),
+            ShapeType::Drawing(s) => {
+                let self_pos = self.pos.pos;
+                s.iter_mut().for_each(|v| {
+                    v.update_scale(scale);
+                    v.update_pos(self_pos + v.pos.pos * scale);
+                })
+            }
             ShapeType::Text {
                 text: _,
                 align: _,
@@ -93,7 +110,9 @@ impl Shape {
             ShapeType::Image { data: _ } => {}
         }
 
+        self.pos.pos = self.pos.position_from_center() * scale;
         self.pos.size = self.pos.size.map(|v| v * scale);
+
         match self.style.as_mut().map(|v| &mut v.stroke) {
             Some(Some(Stroke::Full { color: _, width })) => {
                 *width *= scale;
