@@ -1,6 +1,6 @@
 use algebr::Vec2;
 
-use crate::style::Style;
+use crate::{style::Style, Rect, Shape, ShapeType};
 
 pub type Line = LineBuilder<true>;
 
@@ -30,3 +30,20 @@ impl LineBuilder<false> {
         }
     }
 }
+
+impl Into<Shape> for LineBuilder<true> {
+    fn into(self) -> Shape {
+        let pos = Rect::new()
+            .at((self.from + self.to) / 2.)
+            .with_size((self.from - self.to).abs());
+
+        Shape {
+            pos,
+            style: self.style,
+            shape_type: ShapeType::Line {
+                from: self.from,
+                to: self.to,
+            },
+        }
+    }
+}
